@@ -1,8 +1,8 @@
 from pathlib import Path
-import site
 from rich import print
 import os
 import subprocess as sp
+from .helpers import abs_path
 
 # helpers
 def _params(length=3):
@@ -11,9 +11,6 @@ def _params(length=3):
 def alias(name, executable, _params_length):
     return "alias " + name + "='() { " + executable + " " + _params(3) + "}'"
 
-def abs_path(sub=''):
-    return site.getsitepackages()[0] + '/pnpm' + sub
-
 def install():
     print("Installing pnpm...")
     PATH = abs_path()
